@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_ec2._jsii
@@ -20,7 +20,7 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-rds", "1.61.1", __name__[0:-6], "aws-rds@1.61.1.jsii.tgz"
+    "@aws-cdk/aws-rds", "1.75.0", __name__[0:-6], "aws-rds@1.75.0.jsii.tgz"
 )
 
 __all__ = [
